@@ -34,14 +34,14 @@ class _InnerLoop:
 
     def initialize(self):
         if self.initialization == 'random':
-            self.scores = np.array([self.random_state.randn(view.shape[0]) for view in self.views])
+            self.scores = np.array([self.random_state.randn(view.shape[0], 1) for view in self.views])
         if self.initialization == 'uniform':
-            self.scores = np.array([np.ones(view.shape[0]) for view in self.views])
+            self.scores = np.array([np.ones((view.shape[0], 1)) for view in self.views])
         elif self.initialization == 'unregularized':
             self.scores = PLSInnerLoop(initialization='random', random_state=self.random_state, tol=self.tol).fit(
                 *self.views).scores
         self.scores = self.scores * np.sqrt(self.n - 1) / np.linalg.norm(self.scores, axis=1)[:, np.newaxis]
-        self.weights = [self.random_state.randn(view.shape[1]) for view in self.views]
+        self.weights = [self.random_state.randn(view.shape[1], 1) for view in self.views]
 
     def fit(self, *views: np.ndarray):
         self.views = views
@@ -83,7 +83,7 @@ class _InnerLoop:
         obj = 0
         for (score_i, score_j) in combinations(self.scores, 2):
             obj += score_i.T @ score_j
-        return obj
+        return obj.item()
 
 
 class PLSInnerLoop(_InnerLoop):
@@ -231,7 +231,7 @@ class ElasticInnerLoop(PLSInnerLoop):
                                      tol=self.tol, warm_start=True, random_state=self.random_state))
             else:
                 if alpha == 0:
-                    self.regressors.append(LinearRegression(fit_intercept=False, positive=positive))
+                    self.regressors.append(LinearRegression(fit_intercept=False))
                 elif l1_ratio == 0:
                     if positive:
                         self.regressors.append(
@@ -262,11 +262,11 @@ class ElasticInnerLoop(PLSInnerLoop):
         else:
             self.elastic_solver(self.views[view_index], target, view_index)
         _check_converged_weights(self.weights[view_index], view_index)
-        self.scores[view_index] = (self.views[view_index] @ self.weights[view_index]).ravel()
+        self.scores[view_index] = (self.views[view_index] @ self.weights[view_index])
 
     @ignore_warnings(category=ConvergenceWarning)
     def elastic_solver(self, X, y, view_index):
-        self.weights[view_index] = self.regressors[view_index].fit(X, y.ravel()).coef_
+        self.weights[view_index] = np.expand_dims(self.regressors[view_index].fit(X, y.ravel()).coef_, 1)
         self.weights[view_index] /= np.linalg.norm(self.views[view_index] @ self.weights[view_index]) / np.sqrt(self.n)
 
     @ignore_warnings(category=ConvergenceWarning)
@@ -340,8 +340,8 @@ class ADMMInnerLoop(ElasticInnerLoop):
 
         _check_Parikh2014(self.mu, self.lam, self.views)
 
-        self.eta = [np.ones((view.shape[0])) * eta for view, eta in zip(self.views, self.eta)]
-        self.z = [np.zeros((view.shape[0])) for view in self.views]
+        self.eta = [np.ones((view.shape[0], 1)) * eta for view, eta in zip(self.views, self.eta)]
+        self.z = [np.zeros((view.shape[0], 1)) for view in self.views]
         self.l1_ratio = [1] * len(self.views)
 
     def update_view(self, view_index: int):
@@ -427,7 +427,7 @@ class SpanCCAInnerLoop(_InnerLoop):
         self.positive = _process_parameter('positive', self.positive, False, len(self.views))
 
     def inner_iteration(self):
-        c = self.random_state.randn(self.rank)
+        c = self.random_state.randn(self.rank, 1)
         c /= np.linalg.norm(c)
         a = self.P @ np.diag(self.D) @ c
         u = self.update(a, self.c[0])
@@ -586,7 +586,7 @@ def _support_soft_thresh(x, support, positive=False):
         u = np.clip(x, 0, None)
     else:
         u = np.abs(x)
-    idx = np.argpartition(x, x.shape[0] - support)
+    idx = np.argpartition(x.ravel(), x.shape[0] - support)
     u[idx[:-support]] = 0
     return u * np.sign(x)
 
