@@ -4,6 +4,7 @@ import numpy as np
 import tensorly as tl
 from scipy.linalg import sqrtm
 from sklearn.metrics.pairwise import pairwise_kernels
+from sklearn.utils.validation import check_is_fitted
 from tensorly.decomposition import parafac
 
 from .cca_base import _CCA_Base
@@ -30,7 +31,7 @@ class TCCA(_CCA_Base):
     """
 
     def __init__(self, latent_dims: int = 1, scale=True, centre=True, copy_data=True, random_state=None,
-                 c: Iterable[float] = None):
+                 c: Union[Iterable[float], float] = None):
         """
         Constructor for TCCA
 
@@ -69,9 +70,7 @@ class TCCA(_CCA_Base):
         M_parafac = parafac(M, self.latent_dims, verbose=True)
         self.alphas = [cov_invsqrt @ fac for i, (view, cov_invsqrt, fac) in
                        enumerate(zip(views, covs_invsqrt, M_parafac.factors))]
-        self.scores = [view @ self.alphas[i] for i, view in enumerate(views)]
         self.weights = self.alphas
-        self.scores = [view @ self.weights[i] for i, view in enumerate(views)]
         return self
 
     def _setup_tensor(self, *views: np.ndarray, **kwargs):
@@ -102,7 +101,7 @@ class KTCCA(TCCA):
     """
 
     def __init__(self, latent_dims: int = 1, scale: bool = True, centre=True, copy_data=True, random_state=None,
-                 eps=1e-3, c: Iterable[float] = None,
+                 eps=1e-3, c: Union[Iterable[float], float] = None,
                  kernel: Iterable[Union[float, callable]] = None,
                  gamma: Iterable[float] = None,
                  degree: Iterable[float] = None, coef0: Iterable[float] = None,
@@ -168,6 +167,7 @@ class KTCCA(TCCA):
         :param views: numpy arrays with the same number of rows (samples) separated by commas
         :param kwargs: any additional keyword arguments required by the given model
         """
+        check_is_fitted(self, attributes=['alphas'])
         views = check_views(*views, copy=self.copy_data, accept_sparse=self.accept_sparse)
         if view_indices is None:
             view_indices = np.arange(len(views))
